==> ejc-signaturemanage-api-3.0.1-20211230.081512-82-sources.jar: com.ejianc.business.signaturemanage/vo/InitSignatureVO.java <==
package com.ejianc.business.signaturemanage.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * @author baipengyan
 * @description: 发起签章
 * @date 2021/12/2 10:22
 */
public class InitSignatureVO {
    private static final long serialVersionUID = 1L;

    // @NotNull(message = "业务id不能为空！")
    private java.lang.Long billId; // 业务id
    // @NotEmpty(message = "来源业务单据类型不能为空！")
    private java.lang.String billType; // 来源业务单据类型
    // @NotEmpty(message = "refcode不能为空！")
    private java.lang.String billRefCode; // refcode
    // @NotNull(message = "业务文件id不能为空！")
    private java.lang.Long billDocId; // 业务文件id
    // @NotEmpty(message = "业务文件名称不能为空！")
    private java.lang.String billDocumentName; // 业务文件名称
    private java.lang.String billDocumentType; // 业务文件类型
    // @NotEmpty(message = "发起方名称不能为空！")
    private java.lang.String tenantName; // 发起方名称
    private java.lang.String signRequirements; // 签署要求
    private java.lang.String creatorName; // 创建人名称
    private java.lang.String creatorContact; // 创建人联系方式

    // @Valid
    // @NotEmpty(message = "签署方信息不能为空！")
    private List<InitSignatoryVO> signMgrSignatoryEntities = new ArrayList<>(); // 签署方信息


    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }

    public String getBillType() {
        return billType;
    }

    public void setBillType(String billType) {
        this.billType = billType;
    }

    public String getBillRefCode() {
        return billRefCode;
    }

    public void setBillRefCode(String billRefCode) {
        this.billRefCode = billRefCode;
    }

    public Long getBillDocId() {
        return billDocId;
    }

    public void setBillDocId(Long billDocId) {
        this.billDocId = billDocId;
    }

    public String getBillDocumentName() {
        return billDocumentName;
    }

    public void setBillDocumentName(String billDocumentName) {
        this.billDocumentName = billDocumentName;
    }

    public String getBillDocumentType() {
        return billDocumentType;
    }

    public void setBillDocumentType(String billDocumentType) {
        this.billDocumentType = billDocumentType;
    }

    public String getTenantName() {
        return tenantName;
    }

    public void setTenantName(String tenantName) {
        this.tenantName = tenantName;
    }

    public String getSignRequirements() {
        return signRequirements;
    }

    public void setSignRequirements(String signRequirements) {
        this.signRequirements = signRequirements;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getCreatorContact() {
        return creatorContact;
    }

    public void setCreatorContact(String creatorContact) {
        this.creatorContact = creatorContact;
    }

    public List<InitSignatoryVO> getSignMgrSignatoryEntities() {
        return signMgrSignatoryEntities;
    }

    public void setSignMgrSignatoryEntities(List<InitSignatoryVO> signMgrSignatoryEntities) {
        this.signMgrSignatoryEntities = signMgrSignatoryEntities;
    }
}

==> ejc-signaturemanage-api-3.0.1-20220209.024407-92-sources.jar: com.ejianc.business.signaturemanage/vo/InitSignatureVO.java <==
package com.ejianc.business.signaturemanage.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * @author baipengyan
 * @description: 发起签章
 * @date 2021/12/2 10:22
 */
public class InitSignatureVO {
    private static final long serialVersionUID = 1L;

    // @NotNull(message = "业务id不能为空！")
    private java.lang.Long billId; // 业务id
    // @NotEmpty(message = "来源业务单据类型不能为空！")
    private java.lang.String billType; // 来源业务单据类型
    private String billCode; // 单据编号
    private String contractName; // 合同名称
    // @NotEmpty(message = "refcode不能为空！")
    private java.lang.String billRefCode; // refcode
    // @NotNull(message = "业务文件id不能为空！")
    private java.lang.Long billDocId; // 业务文件id
    // @NotEmpty(message = "业务文件名称不能为空！")
    private java.lang.String billDocumentName; // 业务文件名称
    private java.lang.String billDocumentType; // 业务文件类型
    // @NotEmpty(message = "发起方名称不能为空！")
    private java.lang.String tenantName; // 发起方名称
    private java.lang.String signRequirements; // 签署要求
    private java.lang.String creatorName; // 创建人名称
    private java.lang.String creatorContact; // 创建人联系方式

    // @Valid
    // @NotEmpty(message = "签署方信息不能为空！")
    private List<InitSignatoryVO> signMgrSignatoryEntities = new ArrayList<>(); // 签署方信息


    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }

    public String getBillType() {
        return billType;
    }

    public void setBillType(String billType) {
        this.billType = billType;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getBillRefCode() {
        return billRefCode;
    }

    public void setBillRefCode(String billRefCode) {
        this.billRefCode = billRefCode;
    }

    public Long getBillDocId() {
        return billDocId;
    }

    public void setBillDocId(Long billDocId) {
        this.billDocId = billDocId;
    }

    public String getBillDocumentName() {
        return billDocumentName;
    }

    public void setBillDocumentName(String billDocumentName) {
        this.billDocumentName = billDocumentName;
    }

    public String getBillDocumentType() {
        return billDocumentType;
    }

    public void setBillDocumentType(String billDocumentType) {
        this.billDocumentType = billDocumentType;
    }

    public String getTenantName() {
        return tenantName;
    }

    public void setTenantName(String tenantName) {
        this.tenantName = tenantName;
    }

    public String getSignRequirements() {
        return signRequirements;
    }

    public void setSignRequirements(String signRequirements) {
        this.signRequirements = signRequirements;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getCreatorContact() {
        return creatorContact;
    }

    public void setCreatorContact(String creatorContact) {
        this.creatorContact = creatorContact;
    }

    public List<InitSignatoryVO> getSignMgrSignatoryEntities() {
        return signMgrSignatoryEntities;
    }

    public void setSignMgrSignatoryEntities(List<InitSignatoryVO> signMgrSignatoryEntities) {
        this.signMgrSignatoryEntities = signMgrSignatoryEntities;
    }
}
